@@ -579,6 +579,34 @@ class TemClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RollingUpdateApplicationByVersion(self, request):
+        """更新应用部署版本
+
+        :param request: Request instance for RollingUpdateApplicationByVersion.
+        :type request: :class:`tencentcloud.tem.v20210701.models.RollingUpdateApplicationByVersionRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.RollingUpdateApplicationByVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RollingUpdateApplicationByVersion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RollingUpdateApplicationByVersionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
